<template>
  <div>
    <div id="sidebar">
      <recent-violations :violations="violations" />
      <suggestion-counter :suggestions="suggestions"/>
      <div id="headlines">
        <headlines />
      </div>
      <action-buttons
        :has-swiper="hasSwiper"
        :shop="shop" />
    </div>
    <div
      id="laws"
      class="clearfix">
      <div id="maincontent">
        <h1>Laws</h1>
        <section>
          <h2>Towne Laws</h2>
          <ol>
            <li
              v-for="(law, index) in shop.laws"
              :key="law.id"
              :class="{'created-law': index > 4}"
              @click="editLawBody(law, index)">
              {{ law.body }}
            </li>
          </ol>
          <div
            v-if="showLawEditor"
            id="create-laws">
            <h2>Edit law</h2>
            <form>
              <textarea
                id=""
                v-model="lawToEdit.body"
                name=""
                autocorrect="on"/>
              <a
                class="button"
                @click.prevent="saveNewLaw(lawToEdit)">Save Law</a>
            </form>
          </div>
          <div
            v-show="lawCounter < 10"
            id="create-laws">
            <h2>Create your own laws (up to five)</h2>
            <ul class="errors"/>
            <form>
              <textarea
                id=""
                v-model="newLawBody"
                name=""
                autocorrect="on"/>
              <a
                class="button"
                @click.prevent="saveNewLaw({ body: newLawBody })">Save Law</a>
            </form>
          </div>
          <div class="print">
            <h2>Ready to print your laws?</h2>
            <a
              class="button"
              @click.prevent="printLaws">Print Laws</a>
          </div>
        </section>
      </div>
    </div>
  </div>
</template>

<script>
import RecentViolations from "./components/RecentViolation.vue";
import SuggestionCounter from "./components/SuggestionCounter.vue";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";
export default {
  components: {
    RecentViolations,
    SuggestionCounter,
    Headlines,
    ActionButtons,
  },
  props: {
    suggestions: Array,
    violations: Array,
    shop: Object,
    hasSwiper: Boolean
  },
  data() {
    return {
      newLawBody: "",
      lawCounter: this.shop.laws.length,
      lawToEdit: {},
      showLawEditor: false
    };
  },
  methods: {
    clearEditedLawBody() {
      if (this.clearEditedLaw) {
        this.lawToEdit = {};
      }
    },
    saveNewLaw(law) {
      let data = {};
      if (Object.keys(law).length > 1) {
        data = law;
      } else {
        this.lawCounter += 1;
        data = law;
      }
      console.log(data);
      app.session.SetSession()
        .then( () => {
          app.api.Post(`townehall/postLaw/${app.session.data.id}`, data)
          .then(Response => {
            console.log(Response);
            app.Message("Law Saved!", "success");
            this.newLawBody = "";
            this.showLawEditor = false;
            this.$emit("update-laws");
          })
          .catch( x => app.Message(x.error, "error"));
        });
    },
    editLawBody (lawToEdit, indexOfLaw) {
      if(indexOfLaw <= 4) {
        return;
      }
      if (this.showLawEditor === false ) {
        this.lawToEdit = {};
      }
      this.showLawEditor = true;
      this.lawToEdit = lawToEdit;
    },
    printLaws() {
      confirm("Are you ready to print laws?")
        ? app.printer.Enqueue("laws")
        : alert("Print cancelled");
    },
  },
};
</script>

<style lang="css" scoped>
  .created-law {
    text-decoration: underline;
    cursor: pointer;
  }
</style>

